Module engine

Module engine 

Utilities for working with the engine-side, particularly with regards to setting up the entrypoint for your app’s build/export/server processes.

Enums

EngineOperation
A representation of the server-side engine operations that can be performed.

Functions

get_op
Determines the engine operation to be performed by examining environment variables (set automatically by the CLI as appropriate).
run_dflt_engine
A convenience function that automatically runs the necessary engine operation based on the given directive. This provides almost no options for customization, and is usually elided by a macro. More advanced use-cases should bypass this and call the functions this calls manually, with their own configurations.
run_dflt_engine_export_only
A wrapper around run_dflt_engine for apps that only use exporting, and so don’t need to bring in a server integration. This is designed to avoid extra dependencies. If perseus serve is called on an app using this, it will panic! after building everything.