ClientInvariantError

Enum ClientInvariantError 

pub enum ClientInvariantError {
Show 14 variants RenderCfg, GlobalState, IllegalStateRegistration, GlobalStateDowncast, InvalidState { source: Error, }, NoState, InitialState, InitialStateError { source: Error, }, ValidLocaleNotProvided { locale: String, }, Translations, RouterMismatch, WidgetStates, InvalidWidgetPssEntry, BadWidgetRouteMatch { path: String, },
}
Errors that can occur in the browser from certain invariants not being upheld. These should be extremely rare, but, since we don’t control what HTML the browser gets, we avoid panicking in these cases.

Note that some of these invariants may be broken by an app’s own code, such as invalid global state downcasting.

Variants



RenderCfg



GlobalState



IllegalStateRegistration



GlobalStateDowncast



InvalidState

Fields

source: Error


NoState



InitialState



InitialStateError

Fields

source: Error


ValidLocaleNotProvided

Fields

locale: String


Translations



RouterMismatch



WidgetStates



InvalidWidgetPssEntry



BadWidgetRouteMatch

Fields

path: String