Module internal

Module internal 

Internal utilities for lower-level work.

Structs

PageData
Represents the data necessary to render a page, including document metadata.
PageDataPartial
A version of PageData that doesn’t contain the HTML content of the page. This is designed for being to sent to the client as part of a subsequent load, since the browser can render the HTML content of a page on its own.