Internal utilities for lower-level work.
Structs
- Page
Data - Represents the data necessary to render a page, including document metadata.
- Page
Data Partial - A version of
PageDatathat doesn’t contain the HTML content of the page. This is designed for being to sent to the client as part of a subsequent load, since the browser can render the HTML content of a page on its own.